package org.loom.appengine;

import org.loom.annotation.SSLPolicy;
import org.loom.annotation.processor.SSLPolicyAnnotationProcessor;
import org.loom.appengine.utils.AppEngineUtils;
import org.loom.mapping.Event;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Scope;


/**
 * Processes {@link SSLPolicy} annotations in the GAE environment.
 * SSL support in GAE is subject to requirements specified here:
 * http://code.google.com/appengine/docs/java/config/webxml.html#Secure_URLs
 * 
 * This annotation processor will ignore annotations if used inside the 
 * local development environment (as expected). For full, correct behavior,  
 * a MultihostSSLPolicyInterceptor should be injected, though it will only 
 * work when in production.
 * @author icoloma
 *
 */
public class AppEngineSSLPolicyAnnotationProcessor extends SSLPolicyAnnotationProcessor {

	@Override
	public void process(Event event) {
		if (!AppEngineUtils.isDevelopmentEnvironment()) {
			super.process(event);
		}
	}

}
