package org.loom.appengine.converter;

import javax.persistence.Id;

import org.loom.appengine.annotations.RootKey;
import org.loom.appengine.annotations.RootKey.RootKeyType;
import org.loom.binding.AnnotationContainer;
import org.loom.binding.PropertyWrapper;
import org.loom.converter.AnnotationDrivenConverterFactory;
import org.simpleds.annotations.Entity;
import org.simpleds.converter.Converter;
import org.springframework.stereotype.Component;

import com.google.appengine.api.datastore.Key;

/**
 * Create {@link Converter} for {@link Key} properties
 * @author Nacho
 *
 */
@Component
public class JpaKeyConverterFactory implements AnnotationDrivenConverterFactory<Id> {

	/** KeyConverter can be used as a singleton */
	private KeyConverter singleton = new KeyConverter();
	
	@SuppressWarnings("deprecation")
	public org.loom.converter.Converter getConverter(AnnotationContainer propertyWrapper, Id annotation) {
		if (propertyWrapper.getPropertyClass() != Key.class) {
			return null;
		}
		Class<?> containerClass = ((PropertyWrapper)propertyWrapper).getContainerClass();
		Entity entity = containerClass.getAnnotation(Entity.class);
		if (entity != null && entity.parent().length == 0) {
			// root entity, create specific converter
			RootKey rootKey = propertyWrapper.getAnnotation(RootKey.class);
			return rootKey != null && rootKey.type() == RootKeyType.NAME? new KeyNameConverter(containerClass) : new KeyIdConverter(containerClass);
		}
		return singleton;
	}
	
	public Class<Id> getAnnotationClass() {
		return Id.class;
	}

}
