package org.loom.simpleds;

import java.util.List;

import org.loom.paged.PagedListData;
import org.loom.paged.SortOrder;
import org.simpleds.PagedList;

import com.google.appengine.api.datastore.Query.SortDirection;
import com.google.appengine.api.datastore.Query.SortPredicate;

/**
 * Transforms a simpleds {@link PagedList} class into a 
 * {@link PagedListData} interface.
 * This class is used to transforms simpleds paged lists for 
 * presdentation using loom tags. 
 * @author icoloma
 *
 */
public class PagedListAdapter<T> implements PagedListData<T> {

	/** the underlying PagedList container */
	private PagedList<T> data;
	
	public PagedListAdapter(PagedList<T> data) {
		this.data = data;
	}
	
	@Override
	public String getId() {
		// TODO to be implemented
		return null;
	}

	public List<T> getData() {
		return data.getData();
	}

	public int getNextPageRecordIndex() {
		return data.getNextPageRecordIndex();
	}

	public int getTotalPages() {
		return data.getTotalPages();
	}

	public int getTotalRecords() {
		return data.getTotalResults();
	}

	public boolean isEmpty() {
		return data.isEmpty();
	}

	public int getPageIndex() {
		return data.getPageIndex();
	}

	public int getPageSize() {
		return data.getPageSize();
	}

	public int getRecordIndex() {
		return data.getFirstRecordIndex();
	}

	public SortOrder getSortOrder() {
		List<SortPredicate> predicates = data.getSortPredicates();
		return predicates.isEmpty()? null : predicates.get(0).getDirection() == SortDirection.ASCENDING? SortOrder.ASCENDING : SortOrder.DESCENDING;
	}

	public String getSortProperty() {
		List<SortPredicate> predicates = data.getSortPredicates();
		return predicates.isEmpty()? null : predicates.get(0).getPropertyName();
	}

}
