package org.loom.simpleds;

import java.util.List;

import org.codehaus.jackson.annotate.JsonAutoDetect;
import org.codehaus.jackson.annotate.JsonMethod;
import org.codehaus.jackson.annotate.JsonProperty;
import org.simpleds.PagedList;

/**
 * Mixin used to serialize {@link PagedList} instances using Jackson.
 * To use, invoke
 * <pre>
 * objectMapper.getSerializationConfig().addMixInAnnotations(PagedList.class, PagedListJacksonMixIn.class);
 * </pre>
 * Details about mixins in Jackson can be seen <a href="http://wiki.fasterxml.com/JacksonMixInAnnotations">here</a>
 * @author icoloma
 *
 */
@JsonAutoDetect(JsonMethod.NONE)
public interface PagedListJacksonMixin {

	  @JsonProperty 
	  List<Object> getData();
	  
	  @JsonProperty
	  int getTotalResults();
	  
	  @JsonProperty
	  int getTotalPages();
	  
	  @JsonProperty
	  int getPageIndex();
	  
}
